@@ -37,6 +37,7 @@
 }
 
 "boxplot.acm" <- function (x, xax = 1, ...) {
+    # correction d'un bug par P. Cornillon 29/10/2004
     if (!inherits(x, "acm")) 
         stop("Object of class 'acm' expected")
     if ((xax < 1) || (xax > x$nf)) 
@@ -49,18 +50,18 @@
         sco.boxplot(x$l1[, xax], oritab[, 1:nvar], clab = 1)
     else if (nvar <= 14) {
         par(mfrow = c(1, 2))
-        sco.boxplot(x$l1[, 1], oritab[, 1:(nvar%/%2)], clab = 1.3)
-        sco.boxplot(x$l1[, 1], oritab[, (nvar%/%2 + 1):nvar], 
+        sco.boxplot(x$l1[, xax], oritab[, 1:(nvar%/%2)], clab = 1.3)
+        sco.boxplot(x$l1[, xax], oritab[, (nvar%/%2 + 1):nvar], 
             clab = 1.3)
     }
     else {
         par(mfrow = c(1, 3))
         if ((a0 <- nvar%/%3) < nvar/3) 
             a0 <- a0 + 1
-        sco.boxplot(x$l1[, 1], oritab[, 1:a0], clab = 1.6)
-        sco.boxplot(x$l1[, 1], oritab[, (a0 + 1):(2 * a0)], 
+        sco.boxplot(x$l1[, xax], oritab[, 1:a0], clab = 1.6)
+        sco.boxplot(x$l1[, xax], oritab[, (a0 + 1):(2 * a0)], 
             clab = 1.6)
-        sco.boxplot(x$l1[, 1], oritab[, (2 * a0 + 1):nvar], 
+        sco.boxplot(x$l1[, xax], oritab[, (2 * a0 + 1):nvar], 
             clab = 1.6)
     }
 }
