@@ -2,10 +2,9 @@
     if (!is.data.frame(df)) 
         stop("data.frame expected")
     lig <- nrow(df)
-    col <- ncol(df)
     if (any(df < 0)) 
         stop("negative entries in table")
-    if ((N <- sum(df)) == 0) 
+    if ((sum(df)) == 0) 
         stop("all frequencies are zero")
     if (length(eff) != lig) 
         stop("non convenient dimension")
